@@ -2,24 +2,26 @@ context("palettes")
 
 test_that("palettes are returned", {
 
-  dfv <- viridis()
-  dfp <- plasma()
-  dfi <- inferno()
-  dfm <- magma()
-  dfc <- cividis()
-  expect_true(nrow(dfv) == 256 & ncol(dfv) == 3)
-  expect_true(nrow(dfp) == 256 & ncol(dfp) == 3)
-  expect_true(nrow(dfi) == 256 & ncol(dfi) == 3)
-  expect_true(nrow(dfm) == 256 & ncol(dfm) == 3)
-  expect_true(nrow(dfc) == 256 & ncol(dfc) == 3)
-
   expect_error(colour_values(1:5, palette = "mypalette"), "unknown palette")
 
-  expect_silent(colour_values(1, palette = "viridis"))
-  expect_silent(colour_values(1, palette = "plasma"))
-  expect_silent(colour_values(1, palette = "inferno"))
-  expect_silent(colour_values(1, palette = "magma"))
-  expect_silent(colour_values(1, palette = "cividis"))
+  all_palettes <- color_palettes()
+  expect_true( length(all_palettes) == 52 )
+
+  for( palette in all_palettes ) {
+    expect_silent( colour_values(1, palette = palette ))
+    res <- colourvalues::get_palette( palette )
+    expect_true( ncol( res ) == 3 & nrow( res ) == 256 )
+
+    ## And call teh function directly
+    res <- eval(parse(text = paste0(palette, "()")))
+    expect_true( ncol( res ) == 3 )
+  }
+
+  expect_error( colourvalues::get_palette("test"), "not a valid palette" )
+
+  # lns <- readLines("./R/palettes.R")
+  # funs <- lns[ grepl("function\\(\\) rcpp_", lns ) ]
+  # gsub(" .*", "", funs )
 
 })
 
